@@ -5,21 +5,29 @@ extensions = [
     'sphinx.ext.autodoc', 'sphinx.ext.autosummary', 'sphinx.ext.doctest',
     'sphinx.ext.todo', 'sphinx.ext.viewcode', 'sphinx.ext.mathjax'
 ]
-project = 'remt'
+project = 'Remt'
 source_suffix = '.rst'
 master_doc = 'index'
 
+title = 'Remt - Note-taking Support Tool'
 version = release = remt.__version__
-copyright = 'remt team'
+copyright = 'Remt team'
 
-epub_basename = 'remt - {}'.format(version)
-epub_author = 'remt team'
+epub_basename = 'Remt - {}'.format(version)
+epub_author = 'Remt team'
 
 todo_include_todos = True
 
 html_theme = 'sphinx_rtd_theme'
 html_static_path = ['static']
 html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
-html_style = 'remt.css'
+
+latex_fout = 'remt-{}.tex'.format(version)
+latex_documents = [
+    ('index', latex_fout, title, 'Remt team', 'manual', False)
+]
+latex_elements = {
+    'papersize': 'a4paper',
+}
 
 # vim: sw=4:et:ai
