@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -27,20 +27,45 @@ import json
 import logging
 import operator
 import os
+import typing as tp
 from cytoolz.dicttoolz import assoc  # type: ignore
 from cytoolz.functoolz import compose  # type: ignore
 from datetime import datetime
 from functools import partial
+from asyncssh.sftp import SFTPClient  # type: ignore
 
-from remt.error import FileError
+from remt.error import FileError, ConnectionError
 
 logger = logging.getLogger(__name__)
 
 BASE_DIR = '/home/root/.local/share/remarkable/xochitl'
+META_EXT = {'.content', '.metadata'}
 
 fn_local = os.path.join
 
-def fn_path(data, base=BASE_DIR, ext='.*'):
+class MetaContent(tp.TypedDict):
+    fileType: str
+    lastOpenedPage: int
+    lineHeight: int
+    pageCount: int
+
+class Meta(tp.TypedDict):
+    uuid: str
+    deleted: bool
+    lastModified: str
+    metadatamodified: bool
+    modified: bool
+    parent: str
+    pinned: bool
+    synced: bool
+    type: str
+    version: int
+    visibleName: str
+    content: MetaContent
+
+MetaDir = dict[str, Meta]
+
+def fn_path(data: Meta, base: str=BASE_DIR, ext: str='.*') -> str:
     """
     Having metadata object create UUID based path of a file created by
     reMarkable tablet.
@@ -55,7 +80,7 @@ def fn_remote(fn: str) -> str:
     """
     return os.path.join(BASE_DIR, fn)
 
-def create_metadata(is_dir, parent_uuid, name):
+def create_metadata(is_dir: bool, parent_uuid: str, name: str) -> Meta:
     now = datetime.utcnow()
     tstamp = int(now.timestamp() * 1000)
     type = 'CollectionType' if is_dir else 'DocumentType'
@@ -71,9 +96,9 @@ def create_metadata(is_dir, parent_uuid, name):
         'version': 0,
         'visibleName': name,
     }
-    return data
+    return tp.cast(Meta, data)
 
-def to_path(data, meta):
+def to_path(data: Meta, meta: MetaDir) -> str:
     parent = data.get('parent')
     name = data['visibleName']
     if parent:
@@ -81,14 +106,14 @@ def to_path(data, meta):
     else:
         return name
 
-def resolve_uuid(meta):
+def resolve_uuid(meta: MetaDir) -> MetaDir:
     meta = {
         k: assoc(v, 'uuid', k) for k, v in meta.items()
         if v.get('parent') != 'trash'
     }
     return {to_path(data, meta): data for data in meta.values()}
 
-def fn_metadata(meta, path):
+def fn_metadata(meta: MetaDir, path: str) -> Meta:
     """
     Get reMarkable tablet file metadata or raise file not found error if no
     metadata for path is found.
@@ -107,9 +132,9 @@ def is_meta(fn: str) -> bool:
 
     :param fn: Filename to be checked.
     """
-    return fn.endswith('.content') or fn.endswith('.metadata')
+    return any(fn.endswith(ext) for ext in META_EXT)
 
-async def ls_remote(sftp):
+async def ls_remote(sftp: SFTPClient) -> dict[str, float]:
     """
     List reMarkable tablet meta files.
     """
@@ -117,14 +142,16 @@ async def ls_remote(sftp):
     items = (f for f in items if is_meta(f.filename))
     return {f.filename: f.attrs.mtime for f in items}
 
-def ls_local(dir_meta: str):
+def ls_local(dir_meta: str) -> dict[str, float]:
     """
     List reMarkable tablet meta files in local cache.
     """
     files = glob.glob(fn_local(dir_meta, '*'))
     return {os.path.basename(fn): os.stat(fn).st_mtime for fn in files}
 
-def find_meta_update(files_remote, files_local):
+def find_meta_update(
+        files_remote: dict[str, float], files_local: dict[str, float]
+    ) -> tp.Iterable[str]:
     """
     Find reMarkable tablet meta files, which need to be updated in local
     cache.
@@ -132,14 +159,16 @@ def find_meta_update(files_remote, files_local):
     items = (f for f, t in files_remote.items() if t > files_local.get(f, 0))
     yield from items
 
-def find_meta_delete(files_remote, files_local):
+def find_meta_delete(
+        files_remote: dict[str, float], files_local: dict[str, float],
+    ) -> tp.Iterable[str]:
     """
     Find reMarkable tablet meta files, which need to be removed from local
     cache.
     """
     yield from (f for f in files_local if f not in files_remote)
 
-async def sync_meta(sftp, dir_meta):
+async def sync_meta(sftp: SFTPClient, dir_meta: str) -> None:
     """
     Synchronize metadata from reMarkable tablet to local cache.
 
@@ -152,7 +181,7 @@ async def sync_meta(sftp, dir_meta):
     # update new and out-of-date meta files
     files = find_meta_update(files_remote, files_local)
     files = [fn_remote(f) for f in files]
-    await sftp.mget(files, dir_meta, preserve=True)
+    await sftp.mget(files, dir_meta, preserve=True, recurse=True)
     logger.info('fetched {} files into local cache'.format(len(files)))
 
     # remove metadata, which does not exist on reMarkable tablet anymore
@@ -162,7 +191,7 @@ async def sync_meta(sftp, dir_meta):
         os.unlink(fn_local(dir_meta, fn))
     logger.info('removed {} files from local cache'.format(len(files)))
 
-def read_meta(dir_meta):
+def read_meta(dir_meta: str) -> MetaDir:
     """
     Read metadata from a reMarkable tablet.
     """
@@ -196,6 +225,10 @@ def cache_dir(host: str) -> str:
     :param host: reMarkable tablet hostname.
     """
     mac = getmac.get_mac_address(hostname=host)
+    if mac is None:
+        raise ConnectionError(
+            'Cannot get MAC address for reMarkable tablet at {}'.format(host)
+        )
     base = os.path.expanduser('~')
     return os.path.join(base, '.cache/remt', mac)
 
