@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ def test_ls_filter_parent_uuid_null():
 
 def test_read_config_error():
     """
-    Test if error is raised when no `remt` configuration project is found.
+    Test if error is raised when no Remt configuration project is found.
     """
     with mock.patch.object(os.path, 'exists') as exists:
         exists.return_value = False
