@@ -1,8 +1,8 @@
 
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 #
 
 """
-Unit tests for `remt` project utilities.
+Unit tests for Remt project utilities.
 """
 
 from cytoolz.functoolz import flip  # type: ignore
