@@ -1,7 +1,7 @@
 #
-# remt - reMarkable tablet command-line tools
+# remt - note-taking support tool for reMarkable tablet
 #
-# Copyright (C) 2018-2020 by Artur Wroblewski <wrobell@riseup.net>
+# Copyright (C) 2018-2021 by Artur Wroblewski <wrobell@riseup.net>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,18 +18,24 @@
 #
 
 """
-`remt` project utilities.
+Remt project utilities.
 """
 
+import typing as tp
+from collections.abc import Sequence
 from itertools import groupby, chain
 from operator import attrgetter
 from cytoolz.itertoolz import partition  # type: ignore
 
+T = tp.TypeVar('T')
+
 flatten = chain.from_iterable
-to_point = attrgetter('x', 'y')
 to_point_y = attrgetter('y')
 
-def split(key, seq):
+def split(
+        key: tp.Callable[..., bool],
+        seq: Sequence[tp.Any],
+    ) -> tp.Iterable[tuple[tp.Any, ...]]:
     """
     Split sequence by a function key.
 
